import { Icon } from '@iconify/react/dist/iconify.js';
import dayjs from 'dayjs';
import { useAtomValue } from 'jotai';
import { isEmpty, isEqual } from 'lodash-es';
import { useMemo } from 'react';
import { Link } from 'react-router-dom';
import { activeSchemeAtom, useSchemeList } from '../../stores/schemes';
import styles from './SchemeList.module.css';

function OperateButtons() {
  return (
    <div className={styles.operates_buttons}>
      <Link to="new" className="button">
        New Scheme
      </Link>
    </div>
  );
}

type SchemeItemProps = {
  item: ReturnType<typeof useSchemeList>[number];
};

function SchemeItem({ item }: SchemeItemProps) {
  const activedScheme = useAtomValue(activeSchemeAtom);
  const isActived = useMemo(() => isEqual(activedScheme, item.id), [activedScheme, item.id]);

  return (
    <div>
      <div>{item.name}</div>
      <div>
        <div>created at {dayjs(item.createdAt).format('YYYY-MM-DD')}</div>
        <div>{isActived && <Icon icon="tabler:check" />}</div>
      </div>
    </div>
  );
}

function SchemesItems() {
  const schemes = useSchemeList();

  return (
    <div className={styles.scheme_items}>
      {isEmpty(schemes) && <div className={styles.empty_prompt}>Create a scheme first.</div>}
      {schemes.map((item) => (
        <SchemeItem key={item.id} item={item} />
      ))}
    </div>
  );
}

export function SchemeList() {
  return (
    <div className={styles.scheme_list}>
      <OperateButtons />
      <SchemesItems />
    </div>
  );
}
